<?php
// Autor (c) Miroslav Novak, www.platiti.cz
// Pouzivani bez souhlasu autora neni povoleno
// #Ver:PRV101-56-g411a2eed:2023-07-24#

namespace Platiti\GPWebPayGpeNs\WooCommerce;

if (!defined('Platiti\\GPWebPayGpeNs\\UniModul\\ConstUniModulVarPath')) define('Platiti\\GPWebPayGpeNs\\UniModul\\ConstUniModulVarPath', wp_upload_dir()['basedir'] . '/UniModul');

use DirectoryIterator;
use Exception;
use Platiti\GPWebPayGpeNs\UniModul\MysqliConnectionShared;
use Platiti\GPWebPayGpeNs\UniModul\UniModul;
use Platiti\GPWebPayGpeNs\UniModul\UniLogger;

use function Platiti\GPWebPayGpeNs\UniModul\BeginUniErr;
use function Platiti\GPWebPayGpeNs\UniModul\EndUniErr;
use function Platiti\GPWebPayGpeNs\UniModul\ExceptionUniErr;



require_once(__DIR__ ."/UniModul/UniModul.php");


/**
 * @return void
 */
function unimodul_plugin_activated() {
	try {
		BeginUniErr();
		$logger = new UniLogger();

		UniModul::moduleInstallVarDirStatic($logger);
		UniModul::moduleInstallDatabaseStatic(new MysqliConnectionShared(DB_HOST, DB_USER, DB_PASSWORD, DB_NAME), $logger);

		$binderName = basename(dirname(__DIR__));
		// delete old submodules
		if (preg_match("@^(.*)Binder$@", $binderName, $matches)) {
			$uniModulName = $matches[1];
			$ddirs = glob(WP_PLUGIN_DIR . "/{$uniModulName}Binder?*");
			if ($ddirs === false) return;
			foreach($ddirs as $f) {
				$logger->writeLog("Info: ADAPTER deleting obsolete payment module submethod {$f}");
				deleteFilesThenSelf($f);
			}
		}


		EndUniErr();
	} catch (Exception $ex) {
		ExceptionUniErr($ex);
	}
}


/**
 * @param string $folder
 * @return void
 */
function deleteFilesThenSelf($folder) {
	foreach(new DirectoryIterator($folder) as $f) {
		if($f->isDot()) continue; // skip . and ..
		if ($f->isFile()) {
			unlink($f->getPathname());
		} else if($f->isDir()) {
			deleteFilesThenSelf($f->getPathname());
		}
	}
	rmdir($folder);
}

/**
 * @param array<string, mixed> $options
 * @return mixed
 */
function wc_adapter_upgrader_package_options($options) {
	if(strpos($options['package'], 'WooCommerceAdapter') !== false){
		$options['clear_destination'] = false;
		$options['abort_if_destination_exists'] = false;
	}
	return $options;
}